Welcome to La Forge's documentation!
======================================
.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   tutorial1
   tutorial2
   tutorial3
   hyper_model
   gp_visualization
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
